@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 
-# $Id: IPAccess.pm,v 1.2 2003/05/27 22:42:05 unimlo Exp $
+# $Id: IPAccess.pm,v 1.5 2003/05/28 14:38:59 unimlo Exp $
 
 package Net::ACL::File::IPAccessRule;
 
@@ -10,7 +10,7 @@ use vars qw( $VERSION @ISA );
 ## Inheritance ##
 
 @ISA     = qw( Net::ACL::Rule );
-$VERSION = '0.02';
+$VERSION = '0.03';
 
 ## Module Imports ##
 
@@ -25,7 +25,10 @@ sub asconfig
  my $name = shift;
  my $match = $this->{_match}->[0];
  my $net = $match->net if defined $match;
- my $str = $net->base . ' ' . $net->hostmask if defined $net;
+ my $str = '';
+ $str = $net->base if defined $net;
+ $str .= ' ' . $net->hostmask if defined $net && $net->bits != 32;
+ $str = 'any' if defined $net && $net->bits == 0;
  return 'access-list ' . $name . ' ' . $this->action_str . ($str eq '' ? '' : ' ' . $str) . "\n";
 }
 
@@ -39,11 +42,11 @@ use vars qw( $VERSION @ISA );
 ## Inheritance ##
 
 @ISA     = qw( Net::ACL::File::Standard );
-$VERSION = '0.02';
+$VERSION = '0.03';
 
 ## Module Imports ##
 
-use Net::ACL::File;
+use Net::ACL::File::Standard;
 use Carp;
 
 ## Net::ACL::File Class Auto Registration Code ##
@@ -54,19 +57,24 @@ Net::ACL::File->add_listtype('access-list',__PACKAGE__,'access-list');
 
 sub loadmatch
 {
- my ($this,$line) = @_;
- $line =~ s/ +/ /g;
- croak "Configuration line format error in line: '$line'"
+ my ($this,$lines) = @_;
+
+ foreach my $line ($lines =~ /\n./ ? $lines->all : $lines) # For some reasons we got more then one!
+  {
+   $line =~ s/ +/ /g;
+   next if $line =~ /^access-list (\d{3}) /i;
+   croak "Configuration line format error in line: '$line'"
 	unless $line =~ /^access-list ([^ ]+) (permit|deny)(.*)$/i;
- my ($name,$action,$data) = ($1,$2,$3);
- $data =~ s/^ //;
- $data =~ s/ /#/;
- my $rule = new Net::ACL::File::IPAccessRule(
+   my ($name,$action,$data) = ($1,$2,$3);
+   $data =~ s/^ //;
+   $data =~ s/ /#/;
+   my $rule = new Net::ACL::File::IPAccessRule(
 	Action	=> $action
 	);
- $rule->add_match($rule->autoconstruction('Match','Net::ACL::Match::IP','IP',0,$data));
- $this->add_rule($rule);
- $this->name($name);
+   $rule->add_match($rule->autoconstruction('Match','Net::ACL::Match::IP','IP',0,$data));
+   $this->add_rule($rule);
+   $this->name($name);
+  };
 }
 
 ## POD ##
